@@ -23,8 +23,8 @@
 #define PROCESSES_H_
 
 #include "process.h"
-#include <QtCore/QObject>
-#include <QtCore/QHash>
+#include <QObject>
+#include <QHash>
 
 namespace KSysGuard
 {
@@ -58,7 +58,7 @@ namespace KSysGuard
 
     public:
 
-        Processes(const QString &hostname = {}, QObject * parent = nullptr);
+        Processes(const QString &hostname = QString(), QObject * parent = nullptr);
         ~Processes() override;
         enum UpdateFlag {
             StandardInformation = 1,
